==> defit-0.2.0.tar.gz: defit-0.2.0/setup.py <==
import setuptools
import os
# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
setuptools.setup(
    name="deFit",
    version="0.2.0",
    author="Yueqin Hu, Qingshan Liu, Minglan Li",
    author_email="yueqinhu@bnu.edu.cn",
    license='GPL-3',
    description="Fitting Differential Equations to Time Series Data",
    long_description_content_type='text/markdown',
    long_description="\n".join(
        [
            open("README.md").read(),
            # open("CHANGELOG.md").read(),
            # open("AUTHORS.md").read(),
            # open("LICENSE.md").read(),
        ]),
    # description="Use numerical optimization to fit ordinary differential equations (ODEs) to time series data to examine the dynamic relationships between variables or the characteristics of a dynamical system. It can now be used to estimate the parameters of ODEs up to second order.",
    packages=setuptools.find_packages(),
    url="https://github.com/yueqinhu/defit",  # Optional
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
    install_requires=[
        'pandas',
        'scipy',
        'numpy',
        'pathlib',
        'matplotlib',
        'importlib-metadata; python_version == "3.8"',
    ],
    include_package_data=True,
    keywords="ODE, optimization, numerical methods, Intensive longitudinal data, dynamical system, differential equation, time series",  # Optional
    package_data={
        "defit": ["*.txt"],
        "defit":['data/*'],
    },
    project_urls={  # Optional
        "Documentation": "https://github.com/yueqinhu/defit",
        "Source Code": "https://github.com/yueqinhu/defit",
    },
)

==> defit-0.3.0.tar.gz: defit-0.3.0/setup.py <==
import setuptools
import os
# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
setuptools.setup(
    name="deFit",
    version="0.3.0",
    author="Yueqin Hu, Qingshan Liu, Minglan Li",
    author_email="yueqinhu@bnu.edu.cn, liuqingshan@mail.bnu.edu.cn, 202431061029@mail.bnu.edu.cn",
    license='GPL-3',
    description="Fitting Differential Equations to Time Series Data",
    long_description_content_type='text/markdown',
    long_description="\n".join(
        [
            open("README.md").read(),
            # open("CHANGELOG.md").read(),
            # open("AUTHORS.md").read(),
            # open("LICENSE.md").read(),
        ]),
    # description="Use numerical optimization to fit ordinary differential equations (ODEs) to time series data to examine the dynamic relationships between variables or the characteristics of a dynamical system. It can now be used to estimate the parameters of ODEs up to second order.",
    packages=setuptools.find_packages(),
    url="https://github.com/yueqinhu/defit",  # Optional
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
    install_requires=[
        'pandas',
        'scipy',
        'numpy',
        'pathlib',
        'matplotlib',
        'importlib-metadata; python_version == "3.8"',
    ],
    include_package_data=True,
    keywords="ODE, optimization, numerical methods, Intensive longitudinal data, dynamical system, differential equation, time series",  # Optional
    package_data={
        "defit": ["*.txt"],
        "defit":['data/*'],
    },
    project_urls={  # Optional
        "Documentation": "https://github.com/yueqinhu/defit",
        "Source Code": "https://github.com/yueqinhu/defit",
    },
)
